@@ -1,10 +1,11 @@
 @testset "save_everystep Keyword" begin
     #Test whether the result of the process is dependent on 'save_everystep'.
     using DiffEqNoiseProcess, DiffEqBase, Test, Statistics, Random
-    processes = [OrnsteinUhlenbeckProcess(1.0, 1.0, 0.3, 0.0, 0.0, nothing),
+    processes = [
+        OrnsteinUhlenbeckProcess(1.0, 1.0, 0.3, 0.0, 0.0, nothing),
         WienerProcess(0.0, 0.0, nothing),
         CorrelatedWienerProcess([1.0 0.0; 0.0 1.0], 0.0, [0.0; 0.0], nothing),
-        GeometricBrownianMotionProcess(1.0, 1.0, 0.0, 0.0, nothing)
+        GeometricBrownianMotionProcess(1.0, 1.0, 0.0, 0.0, nothing),
     ]
 
     @testset "Noise_process = $(proc.dist)" for proc in processes
